;;; Customistations and set up for using org-mode
(provide 'my-org-mode)
(require 'my-functions)

;;; Always use visual-line-mode and org-indent-mode by default
(add-hook 'org-mode-hook
	  (lambda ()
	    (visual-line-mode 1)
	    (org-indent-mode 1)))

;;; The active org files - all my note files
(setq org-agenda-files nil)
(dolist (fname (files-matching-below "~/notes/active" ".org$"))
  (add-to-list 'org-agenda-files fname))
;;;(setq org-agenda-files nil)

;;; Open Appropriate applications for links
(setq org-file-apps
      '((auto-mode . emacs)
	("\\.mm\\'" . default)
	("\\.x?html?\\'" . default)
	("\\.pdf\\'" . default)
	("\\.ods\\'" . default)
	("\\.odt\\'" . default)))

;;; My TODO workflow states and logging
(setq org-drawers nil)
(dolist (elt '("FILE" "PROPERTIES"))
   (add-to-list 'org-drawers elt))

(setq org-todo-keywords
      '((sequence
	 "TASK" ; a task that will probably become something to do
	 "TODO" ; something to do that has not been started
	 "ACTIVE" ; something that is being worked on
	 "BLOCKED" ; something that can no longer be worked on for some reason
	 "|"
	 "DONE"
	 "CANCELLED")))

;;; Command shortcuts
(global-set-key "\C-cl" 'org-store-link)
(global-set-key "\C-cc" 'org-capture)
(global-set-key "\C-ca" 'org-agenda)
(global-set-key "\C-cb" 'org-iswitchb)

;;; Capture setup
(setq org-directory "~/notes")
(setq org-default-notes-file (concat org-directory "/misc.org"))

;;; Capture templates
(setq org-capture-templates
      '(("t" "Todo" entry (file+headline "~/notes/misc.org" "Misc")
	 "* TASK %^{Title}
:LOGBOOK:
- Created: %u
:END:
%?
"
	 :prepend t)
	("o" "Todo (Orb)" entry (file+headline "~/notes/evanidus.org" "Miscellaneous")
	 "* TASK %^{Title} 
:LOGBOOK:
- Created: %u
:END:
%?
"
	 :prepend t)
	("n" "Todo (Naturapet)" entry (file+headline "~/notes/naturapet.org" "Naturapet Jobs")
	 "* TASK %^{Title} 
:LOGBOOK:
- Created: %u
:END:
%?
"
	 :prepend t)
	("e" "Event" entry (file+datetree+prompt "~/notes/events.org")
	 "* %^{Title} %?
")
	("c" "Call" entry (file+headline "~/notes/misc.org" "Calls")
	 "* TASK %^{Title} %U
%?
"
	 :prepend t)
	("s" "Snippet" entry (file+headline "~/notes/fiction/snippets.org" "Snippets")
	 "* %^{Title}
:LOGBOOK:
- Created: %u
:END:
%?
"
	 :prepend t)
	("l" "Link" table-line (file+headline "~/notes/misc.org" "Links" nil))))

;;; Capture from anywhere
(require 'org-protocol)

;;; Keep agenda view uncluttered
(setq org-agenda-skip-scheduled-if-done t)
(setq org-agenda-skip-deadline-if-done t)
(setq org-reverse-note-order t)
(setq org-agenda-span 14)
(setq org-agenda-start-on-weekday nil)

;;; Show pictures by default
(setq org-startup-with-inline-images t)

;;; Get my org notes and display agenda if wanted
(add-hook 'after-init-hook
	  (lambda ()
	    (if (y-or-n-p-with-timeout "Update notes?" 7 t)
		(progn
		  (message "Updating ~/notes...")
		  (shell-command-to-string "svn update ~/notes")))
	    (org-agenda-list)
	    (switch-to-buffer (get-buffer "*Org Agenda*"))))

;;;commit notes on exit (does not add - this could be better)
(defun my-exit ()
  (if (y-or-n-p-with-timeout "Commit changes to notes?" 7 t)
      (progn
	(message "Commiting changes to ~/notes...")
	(shell-command-to-string "svn commit -m '' ~/notes"))))
(add-hook 'kill-emacs-hook 'my-exit)
